@@ -44,7 +44,7 @@
 .remove <- function(this, name)
   rm(list = name, envir = .storage(this), inherits = FALSE);
 
-.clone <- function(this) {
+.clone <- function(this, copy.storage = TRUE) {
   # Copy the information body
   obj <- this;
 
@@ -52,12 +52,14 @@
   obj <- .create.storage(obj);
 
   # Copy the contents of data storage
-  clone.env <- .storage(obj);
-  this.env <- .storage(this);
-  for (field in ls(envir = this.env, all.names = TRUE)) {
-    value <- get(field, envir = this.env, inherits = FALSE);
-    attr(value, "..cloned") <- NULL;
-    assign(field, value, envir = clone.env, inherits = FALSE);
+  if (copy.storage) {
+    clone.env <- .storage(obj);
+    this.env <- .storage(this);
+    for (field in ls(envir = this.env, all.names = TRUE)) {
+      value <- get(field, envir = this.env, inherits = FALSE);
+      attr(value, "..cloned") <- NULL;
+      assign(field, value, envir = clone.env, inherits = FALSE);
+    }
   }
 
   obj;
